Module uim.codec.writer.encoder
===============================
Encoder classes
===============
This package contains all encoders for the Universal Ink Model:

- Version 3.1.0

Sub-modules
-----------
* uim.codec.writer.encoder.base
* uim.codec.writer.encoder.encoder_3_1_0